@@ -9,7 +9,7 @@ MockAccount::MockAccount(QObject *parent)
 {
     registerGet(apiUrl("/api/v1/preferences"), new TestReply("preferences.json", this));
     m_preferences = new Preferences(this);
-    Q_EMIT authenticated();
+    Q_EMIT authenticated(true);
 }
 
 void MockAccount::get(const QUrl &url,
@@ -104,12 +104,11 @@ QNetworkReply *MockAccount::upload(const QUrl &filename, std::function<void(QNet
     return nullptr;
 }
 
-void MockAccount::writeToSettings(QSettings &settings) const
+void MockAccount::writeToSettings()
 {
-    Q_UNUSED(settings)
 }
 
-void MockAccount::buildFromSettings(const QSettings &settings)
+void MockAccount::buildFromSettings(const AccountConfig &settings)
 {
     Q_UNUSED(settings)
 }
