@@ -4,12 +4,11 @@
 #include <QtTest/QtTest>
 
 #include "helperreply.h"
-#include "maintimelinemodel.h"
 #include "mockaccount.h"
-#include "poll.h"
-#include "post.h"
-#include "tagsmodel.h"
-#include "threadmodel.h"
+#include "timeline/maintimelinemodel.h"
+#include "timeline/poll.h"
+#include "timeline/tagstimelinemodel.h"
+#include "timeline/threadmodel.h"
 #include <KLocalizedString>
 #include <QAbstractItemModelTester>
 #include <QSignalSpy>
@@ -57,6 +56,7 @@ private Q_SLOTS:
         statusExampleApi.open(QIODevice::ReadOnly);
 
         MainTimelineModel timelineModel;
+        timelineModel.setName("home");
         QCOMPARE(timelineModel.rowCount({}), 0);
 
         account->streamingEvent(AbstractAccount::StreamingEventType::UpdateEvent, statusExampleApi.readAll());
@@ -73,6 +73,7 @@ private Q_SLOTS:
         account->registerGet(fetchMoreUrl, new TestReply("statuses.json", account));
 
         MainTimelineModel timelineModel;
+        timelineModel.setName("home");
 
         QCOMPARE(timelineModel.rowCount({}), 2);
         QVERIFY(timelineModel.canFetchMore({}));
@@ -89,7 +90,7 @@ private Q_SLOTS:
         });
         account->registerGet(fetchMoreUrl, new TestReply("statuses.json", account));
 
-        TagsModel tagModel;
+        TagsTimelineModel tagModel;
         tagModel.setHashtag("home");
 
         QCOMPARE(tagModel.rowCount({}), 2);
